Export compound data by module
export_compound_module.RdDownload a CSV of a specific data module for one compound.
Usage
export_compound_module(
id,
module = c("overview", "physicochemical", "admet", "targets"),
file = NULL
)
export_compound_module.RdDownload a CSV of a specific data module for one compound.
export_compound_module(
id,
module = c("overview", "physicochemical", "admet", "targets"),
file = NULL
)