fetch_dataset_facets.Rd
Returns available filter values and their counts for the TCMomics database.
fetch_dataset_facets()
A named list of tibbles for each facet field.
if (FALSE) { # \dontrun{ facets <- fetch_dataset_facets() facets$omics_type } # }